@@ -15,12 +15,6 @@ class AppLoader(object):
     CONFIG_MODULE_OBJECT_CLASS = "app_loader.config.Config"
     CONFIG_MASTER_OBJECT_CLASS = "app_loader.config.MasterConfig"
 
-    def disable_autoload(self):
-        self.MODULES_AUTOLOAD = False
-
-    def enable_autoload(self):
-        self.MODULES_AUTOLOAD = True
-
     def load_modules(self):
         """find all leonardo modules from environment"""
         if self.MODULES_AUTOLOAD:
@@ -149,31 +143,32 @@ class AppLoader(object):
             modules = []
 
             try:
-                import pip
-                installed_packages = pip.get_installed_distributions()
+                import pkgutil
+                installed_packages = [p[1]
+                                      for p in pkgutil.iter_modules()
+                                      if p[2]]
             except Exception:
                 installed_packages = []
                 warnings.warn(
-                    'pip is not installed module, scan module is skipped.',
+                    'error during auto loading modules,'
+                    ' scan module is skipped.',
                     RuntimeWarning)
 
-            for package in installed_packages:
+            for pkg_name in installed_packages:
                 # check for default descriptor
-                pkg_names = [k for k in package._get_metadata("top_level.txt")]
-                for pkg_name in pkg_names:
-                    if pkg_name not in self.blacklist:
-                        try:
-                            mod = import_module(pkg_name)
-                            if hasattr(mod, 'default') \
-                                    or hasattr(mod, 'leonardo_module_conf'):
+                if pkg_name not in self.blacklist:
+                    try:
+                        mod = import_module(pkg_name)
+                        if hasattr(mod, 'default') \
+                                or hasattr(mod, 'leonardo_module_conf'):
+                            modules.append(mod)
+                            continue
+                        for key in dir(mod):
+                            if 'LEONARDO' in key:
                                 modules.append(mod)
-                                continue
-                            for key in dir(mod):
-                                if 'LEONARDO' in key:
-                                    modules.append(mod)
-                                    break
-                        except Exception:
-                            pass
+                                break
+                    except Exception:
+                        pass
             self._found_modules = modules
         return self._found_modules
 
@@ -226,7 +221,8 @@ class AppLoader(object):
 
         # extract config keys from module or object
         for key, default_value in conf.items():
-            conf[key] = get_key_from_module(mod, key, default_value, self.CONFIG_PREFIX)
+            conf[key] = get_key_from_module(
+                mod, key, default_value, self.CONFIG_PREFIX)
 
         # support for recursive dependecies
         try:
@@ -330,3 +326,11 @@ class AppLoader(object):
 
         self._urlpatterns = urlpatterns
         return self._urlpatterns
+
+    def disable_autoload(self):
+        '''Just disable autoloading'''
+        self.MODULES_AUTOLOAD = False
+
+    def enable_autoload(self):
+        '''Just enable autoloading'''
+        self.MODULES_AUTOLOAD = True
